import { insert, createComponent, effect, style, template, setAttribute } from 'solid-js/web';
import { mergeProps, getOwner, createSignal, createEffect, on, runWithOwner, Show, createMemo, onMount, createResource, ErrorBoundary, Suspense } from 'solid-js';
import { createIntersectionObserver } from '@solid-primitives/intersection-observer';
import { createScriptLoader } from '@solid-primitives/script-loader';
import { createStore } from 'solid-js/store';

const _tmpl$$z = /*#__PURE__*/template(`<div class="observer-solid-social"></div>`, 2),
      _tmpl$2$1 = /*#__PURE__*/template(`<div class="placeholder-solid-social"></div>`, 2);
const GeneralObserver = props => {
  const props_ = mergeProps({
    height: 0
  }, props);
  const owner = getOwner();
  const [observerReference, setObserverReference] = createSignal();
  const [isVisible, setVisible] = createSignal(false);
  createEffect(on(observerReference, () => {
    const element = observerReference();
    element && createIntersectionObserver(() => [element], ([entry]) => {
      if (entry.intersectionRatio > 0 && owner) {
        setVisible(true);
        runWithOwner(owner, () => props.onEnter?.());
      }
    }, {
      root: undefined,
      rootMargin: '400px',
      threshold: 0
    });
  }));
  return (() => {
    const _el$ = _tmpl$$z.cloneNode(true);

    setObserverReference(_el$);

    insert(_el$, createComponent(Show, {
      get when() {
        return isVisible();
      },

      get fallback() {
        return (() => {
          const _el$2 = _tmpl$2$1.cloneNode(true);

          effect(_$p => style(_el$2, {
            width: '100%',
            ...(props_.height && {
              height: `${props_.height}px`
            })
          }, _$p));

          return _el$2;
        })();
      },

      get children() {
        return props_.children;
      }

    }));

    return _el$;
  })();
};

const _tmpl$$y = /*#__PURE__*/template(`<div class="airtable-base-solid-social"><iframe class="airtable-base" width="100%" height="533"></iframe></div>`, 4);
const AirtableBase = props => {
  const props_ = mergeProps({
    layout: '',
    viewControls: 'on'
  }, props);
  return createComponent(GeneralObserver, {
    get children() {
      const _el$ = _tmpl$$y.cloneNode(true),
            _el$2 = _el$.firstChild;

      _el$.style.setProperty("position", "relative");

      _el$2.style.setProperty("background", "transparent");

      _el$2.style.setProperty("border", "1px solid #ccc");

      effect(_p$ => {
        const _v$ = `airtable-${props_.airtableBaseId}`,
              _v$2 = `//airtable.com/embed/${props_.airtableBaseId}?backgroundColor=green&${!props_.layout ? `` : `layout=${props_.layout}&`}viewControls=${props_.viewControls}`;
        _v$ !== _p$._v$ && setAttribute(_el$2, "title", _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$2, "src", _p$._v$2 = _v$2);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined
      });

      return _el$;
    }

  });
};

const _tmpl$$x = /*#__PURE__*/template(`<div class="airtable-form-solid-social"><iframe class="airtable-form" width="100%" height="533"></iframe></div>`, 4);
const AirtableForm = props => createComponent(GeneralObserver, {
  get children() {
    const _el$ = _tmpl$$x.cloneNode(true),
          _el$2 = _el$.firstChild;

    _el$.style.setProperty("position", "relative");

    _el$2.style.setProperty("background", "transparent");

    _el$2.style.setProperty("border", "1px solid #ccc");

    effect(_p$ => {
      const _v$ = `airtable-${props.airtableFormId}`,
            _v$2 = `//airtable.com/embed/${props.airtableFormId}?backgroundColor=green`;
      _v$ !== _p$._v$ && setAttribute(_el$2, "title", _p$._v$ = _v$);
      _v$2 !== _p$._v$2 && setAttribute(_el$2, "src", _p$._v$2 = _v$2);
      return _p$;
    }, {
      _v$: undefined,
      _v$2: undefined
    });

    return _el$;
  }

});

const _tmpl$$w = /*#__PURE__*/template(`<div class="buzzsprout-solid-social"><iframe class="buzzsprout" scrolling="no"></iframe></div>`, 4);
const Buzzsprout = props => {
  const props_ = mergeProps({
    width: '100%',
    height: '200'
  }, props);
  return createComponent(Show, {
    get when() {
      return /^\d{7}\/\d{7}-[\W\w]+/.test(props_.buzzsproutId);
    },

    get children() {
      return createComponent(GeneralObserver, {
        get children() {
          const _el$ = _tmpl$$w.cloneNode(true),
                _el$2 = _el$.firstChild;

          _el$.style.setProperty("position", "relative");

          effect(_p$ => {
            const _v$ = `buzzsprout-${props_.buzzsproutId}`,
                  _v$2 = `//www.buzzsprout.com/${props_.buzzsproutId}?client_source=small_player&amp;iframe=true`,
                  _v$3 = props_.width,
                  _v$4 = props_.height;
            _v$ !== _p$._v$ && setAttribute(_el$2, "title", _p$._v$ = _v$);
            _v$2 !== _p$._v$2 && setAttribute(_el$2, "src", _p$._v$2 = _v$2);
            _v$3 !== _p$._v$3 && setAttribute(_el$2, "width", _p$._v$3 = _v$3);
            _v$4 !== _p$._v$4 && setAttribute(_el$2, "height", _p$._v$4 = _v$4);
            return _p$;
          }, {
            _v$: undefined,
            _v$2: undefined,
            _v$3: undefined,
            _v$4: undefined
          });

          return _el$;
        }

      });
    }

  });
};

const getPadding$1 = aspectRatio => {
  const config = {
    '1:1': {
      'padding-top': '100%'
    },
    '16:9': {
      'padding-top': '56.25%'
    },
    '4:3': {
      'padding-top': '75%'
    },
    '3:2': {
      'padding-top': '66.66%'
    },
    '8.5': {
      'padding-top': '62.5%'
    }
  };
  return config[aspectRatio];
};
const createStyleSheet = href => {
  const link = document.createElement(`link`);
  link.type = `text/css`;
  link.rel = `stylesheet`;
  link.href = href;
  document.querySelectorAll(`head`)[0].append(link);
};

const _tmpl$$v = /*#__PURE__*/template(`<div class="cinnamon-solid-social"><iframe class="cinnamon" allow="monetization; accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe></div>`, 4);
const Cinnamon = props => createComponent(GeneralObserver, {
  get children() {
    const _el$ = _tmpl$$v.cloneNode(true),
          _el$2 = _el$.firstChild;

    _el$2.style.setProperty("position", "absolute");

    _el$2.style.setProperty("top", "0");

    _el$2.style.setProperty("left", "0");

    _el$2.style.setProperty("width", "100%");

    _el$2.style.setProperty("height", "100%");

    effect(_p$ => {
      const _v$ = {
        position: 'relative',
        width: '100%',
        ...getPadding$1('16:9')
      },
            _v$2 = `cinnamon-${props.cinnamonId}`,
            _v$3 = `//cinnamon.video/embed?v=${props.cinnamonId}`;
      _p$._v$ = style(_el$, _v$, _p$._v$);
      _v$2 !== _p$._v$2 && setAttribute(_el$2, "title", _p$._v$2 = _v$2);
      _v$3 !== _p$._v$3 && setAttribute(_el$2, "src", _p$._v$3 = _v$3);
      return _p$;
    }, {
      _v$: undefined,
      _v$2: undefined,
      _v$3: undefined
    });

    return _el$;
  }

});

const _tmpl$$u = /*#__PURE__*/template(`<iframe class="codepen" allowfullscreen></iframe>`, 2);
const CodePen = props => {
  const props_ = mergeProps({
    height: 500,
    tabs: 'result',
    clickToLoad: false,
    editable: false,
    theme: 'default'
  }, props);
  return createComponent(GeneralObserver, {
    get height() {
      return props_.height;
    },

    get children() {
      const _el$ = _tmpl$$u.cloneNode(true);

      _el$.style.setProperty("width", "100%");

      effect(_p$ => {
        const _v$ = `codepen-${props_.codePenId}`,
              _v$2 = props_.height,
              _v$3 = `//codepen.io/team/codepen/embed${props_.clickToLoad ? '/preview' : ''}/${props_.codePenId}?height=265&theme-id=${props_.theme}&default-tab=${props_.tabs.toString()}${props_.editable ? '&editable=true' : ''}`;
        _v$ !== _p$._v$ && setAttribute(_el$, "title", _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$, "height", _p$._v$2 = _v$2);
        _v$3 !== _p$._v$3 && setAttribute(_el$, "src", _p$._v$3 = _v$3);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined,
        _v$3: undefined
      });

      return _el$;
    }

  });
};

const _tmpl$$t = /*#__PURE__*/template(`<iframe class="codesandbox" allow="geolocation; microphone; camera; midi; vr; accelerometer; gyroscope; payment; ambient-light-sensor; encrypted-media; usb" sandbox="allow-modals allow-forms allow-popups allow-scripts allow-same-origin"></iframe>`, 2);
const CodeSandbox = props => createComponent(GeneralObserver, {
  get children() {
    const _el$ = _tmpl$$t.cloneNode(true);

    _el$.style.setProperty("width", "100%");

    _el$.style.setProperty("height", "500px");

    _el$.style.setProperty("border", "0");

    _el$.style.setProperty("border-radius", "4px");

    _el$.style.setProperty("overflow", "hidden");

    effect(_p$ => {
      const _v$ = `codeSandbox-${props.codeSandboxId}`,
            _v$2 = `//codesandbox.io/embed/${props.codeSandboxId}`;
      _v$ !== _p$._v$ && setAttribute(_el$, "title", _p$._v$ = _v$);
      _v$2 !== _p$._v$2 && setAttribute(_el$, "src", _p$._v$2 = _v$2);
      return _p$;
    }, {
      _v$: undefined,
      _v$2: undefined
    });

    return _el$;
  }

});

const _tmpl$$s = /*#__PURE__*/template(`<div class="egghead-lesson-solid-social"><iframe class="egghead-lesson" allow="autoplay; fullscreen"></iframe></div>`, 4);
const EggheadLesson = props => createComponent(GeneralObserver, {
  get children() {
    const _el$ = _tmpl$$s.cloneNode(true),
          _el$2 = _el$.firstChild;

    _el$2.style.setProperty("position", "absolute");

    _el$2.style.setProperty("top", "0");

    _el$2.style.setProperty("left", "0");

    _el$2.style.setProperty("width", "100%");

    _el$2.style.setProperty("height", "100%");

    effect(_p$ => {
      const _v$ = {
        position: 'relative',
        width: '100%',
        ...getPadding$1('16:9')
      },
            _v$2 = `egghead-${props.lessonId}`,
            _v$3 = `//egghead.io/lessons/${props.lessonId}/embed`;
      _p$._v$ = style(_el$, _v$, _p$._v$);
      _v$2 !== _p$._v$2 && setAttribute(_el$2, "title", _p$._v$2 = _v$2);
      _v$3 !== _p$._v$3 && setAttribute(_el$2, "src", _p$._v$3 = _v$3);
      return _p$;
    }, {
      _v$: undefined,
      _v$2: undefined,
      _v$3: undefined
    });

    return _el$;
  }

});

const _tmpl$$r = /*#__PURE__*/template(`<iframe class="figma" allowfullscreen></iframe>`, 2);
const Figma = propes => {
  const props_ = mergeProps({
    height: 450
  }, propes);
  const regex = /(file|proto)\/([\dA-Za-z]{22,128})(?:\/.*)?$/;
  return createComponent(Show, {
    get when() {
      return regex.test(props_.url);
    },

    get children() {
      return createComponent(GeneralObserver, {
        get height() {
          return props_.height;
        },

        get children() {
          const _el$ = _tmpl$$r.cloneNode(true);

          _el$.style.setProperty("width", "100%");

          effect(_p$ => {
            const _v$ = `figma-${props_.title}`,
                  _v$2 = props_.height,
                  _v$3 = `//www.figma.com/embed?embed_host=mdx-embed&url=https://www.figma.com/${props_.url}`;
            _v$ !== _p$._v$ && setAttribute(_el$, "title", _p$._v$ = _v$);
            _v$2 !== _p$._v$2 && setAttribute(_el$, "height", _p$._v$2 = _v$2);
            _v$3 !== _p$._v$3 && setAttribute(_el$, "src", _p$._v$3 = _v$3);
            return _p$;
          }, {
            _v$: undefined,
            _v$2: undefined,
            _v$3: undefined
          });

          return _el$;
        }

      });
    }

  });
};

let isFlickrScriptAdded = false;
const flickrClasses = ['.flickr-solid-social'].join(',');
const flickrEmbedUrl = '//embedr.flickr.com/assets/client-code.js';
const handleFlickrLoad = () => {
  if (document.querySelector(flickrClasses) && !isFlickrScriptAdded) createScriptLoader({
    src: flickrEmbedUrl,
    onload: () => isFlickrScriptAdded = true
  });
};

const _tmpl$$q = /*#__PURE__*/template(`<span class="flickr" data-flickr-embed="true" data-header="true" data-footer="true"><img width="100%" height="auto"></span>`, 3);
const Flickr = props => createComponent(GeneralObserver, {
  onEnter: handleFlickrLoad,

  get children() {
    const _el$ = _tmpl$$q.cloneNode(true),
          _el$2 = _el$.firstChild;

    effect(_p$ => {
      const _v$ = `//live.staticflickr.com/${props.flickrLink}`,
            _v$2 = props.flickrLink;
      _v$ !== _p$._v$ && setAttribute(_el$2, "src", _p$._v$ = _v$);
      _v$2 !== _p$._v$2 && setAttribute(_el$2, "alt", _p$._v$2 = _v$2);
      return _p$;
    }, {
      _v$: undefined,
      _v$2: undefined
    });

    return _el$;
  }

});

const _tmpl$$p = /*#__PURE__*/template(`<div class="gist"></div>`, 2);
const Gist = props => {
  const [gistResponse, setGistResponse] = createStore({
    gist: {
      isLoading: true,
      div: '',
      file: ''
    }
  });
  const gistId = createMemo(() => props.gistLink.split('/')[1]);
  const gistEmbedScript = createMemo(() => `//gist.github.com/${props.gistLink}.json?callback=gist_callback_${gistId()}`);
  onMount(() => {
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-expect-error
    window[`gist_callback_${gistId()}`] = gist => {
      createStyleSheet(gist.stylesheet);
      setGistResponse({
        gist: {
          isLoading: false,
          div: gist.div,
          file: gist.files[0]
        }
      });
    };

    createScriptLoader({
      src: gistEmbedScript
    });
  });
  return createComponent(GeneralObserver, {
    get children() {
      return createComponent(Show, {
        get when() {
          return !gistResponse.gist.isLoading;
        },

        get children() {
          const _el$ = _tmpl$$p.cloneNode(true);

          effect(() => _el$.innerHTML = gistResponse.gist.div);

          return _el$;
        }

      });
    }

  });
};

const instgrmClasses = ['.instagram-media', '.instagram-media-rendered'].join(',');

const instgrmProcess = () => window.instgrm?.Embeds.process();

const handleInstagrmLoad = () => {
  if (document.querySelector(instgrmClasses) && !window.instgrm) createScriptLoader({
    src: '//www.instagram.com/embed.js'
  });else instgrmProcess();
};

const _tmpl$$o = /*#__PURE__*/template(`<blockquote class="instagram-media instagram-solid-social" data-instgrm-version="12"><a></a></blockquote>`, 4);
const Instagram = props => createComponent(GeneralObserver, {
  onEnter: handleInstagrmLoad,

  get children() {
    const _el$ = _tmpl$$o.cloneNode(true),
          _el$2 = _el$.firstChild;

    insert(_el$2, () => window.instgrm && '');

    effect(() => setAttribute(_el$2, "href", `//instagram.com/p/${props.instagramId}`));

    return _el$;
  }

});

const _tmpl$$n = /*#__PURE__*/template(`<div class="lbry-solid-social"><iframe class="lbry" allow="fullscreen"></iframe></div>`, 4);
const Lbry = props => createComponent(GeneralObserver, {
  get children() {
    const _el$ = _tmpl$$n.cloneNode(true),
          _el$2 = _el$.firstChild;

    _el$2.style.setProperty("position", "absolute");

    _el$2.style.setProperty("top", "0");

    _el$2.style.setProperty("left", "0");

    _el$2.style.setProperty("width", "100%");

    _el$2.style.setProperty("height", "100%");

    effect(_p$ => {
      const _v$ = {
        position: 'relative',
        width: '100%',
        ...getPadding$1('16:9')
      },
            _v$2 = `lbry-${props.lbryId}`,
            _v$3 = `//lbry.tv/$/embed/${props.lbryId}?t=${props.skipTo ?? 0}`;
      _p$._v$ = style(_el$, _v$, _p$._v$);
      _v$2 !== _p$._v$2 && setAttribute(_el$2, "title", _p$._v$2 = _v$2);
      _v$3 !== _p$._v$3 && setAttribute(_el$2, "src", _p$._v$3 = _v$3);
      return _p$;
    }, {
      _v$: undefined,
      _v$2: undefined,
      _v$3: undefined
    });

    return _el$;
  }

});

const linkedInClasses = ['.LI-profile-badge', '.LI-simple-link'].join(',');
const linkedInBadgesUrl = '//platform.linkedin.com/badges/js/profile.js';

const LIRenderAll = () => window.LI && typeof window.LIRenderAll === 'function' && window.LIRenderAll();

const handleLinkedInLoad = () => {
  if (document.querySelector(linkedInClasses) && !(window.LI && window.LIRenderAll)) createScriptLoader({
    src: linkedInBadgesUrl
  });else LIRenderAll();
};

const _tmpl$$m = /*#__PURE__*/template(`<div class="LI-profile-badge linkedin-badge" data-version="v1"><a class="LI-simple-link">Loading</a></div>`, 4);
const LinkedInBadge = props => {
  const props_ = mergeProps({
    badgeType: 'vertical',
    badgeSize: 'medium',
    theme: 'light',
    locale: 'en_US'
  }, props);
  return createComponent(GeneralObserver, {
    onEnter: handleLinkedInLoad,

    get children() {
      const _el$ = _tmpl$$m.cloneNode(true),
            _el$2 = _el$.firstChild;

      effect(_p$ => {
        const _v$ = props_.badgeSize,
              _v$2 = props_.locale,
              _v$3 = props_.badgeType,
              _v$4 = props_.theme,
              _v$5 = props_.username,
              _v$6 = `//uk.linkedin.com/in/${props_.username}?trk=profile-badge`;
        _v$ !== _p$._v$ && setAttribute(_el$, "data-size", _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$, "data-locale", _p$._v$2 = _v$2);
        _v$3 !== _p$._v$3 && setAttribute(_el$, "data-type", _p$._v$3 = _v$3);
        _v$4 !== _p$._v$4 && setAttribute(_el$, "data-theme", _p$._v$4 = _v$4);
        _v$5 !== _p$._v$5 && setAttribute(_el$, "data-vanity", _p$._v$5 = _v$5);
        _v$6 !== _p$._v$6 && setAttribute(_el$2, "href", _p$._v$6 = _v$6);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined,
        _v$3: undefined,
        _v$4: undefined,
        _v$5: undefined,
        _v$6: undefined
      });

      return _el$;
    }

  });
};

const _tmpl$$l = /*#__PURE__*/template(`<div class="listennotes-episode-solid-social"><iframe class="listennotes-episode" frameborder="0" scrolling="no" loading="lazy"></iframe></div>`, 4);
const ListenNotesEpisode = props => {
  const props_ = mergeProps({
    width: '100%',
    height: '180px'
  }, props);
  return createComponent(GeneralObserver, {
    get children() {
      const _el$ = _tmpl$$l.cloneNode(true),
            _el$2 = _el$.firstChild;

      _el$.style.setProperty("position", "relative");

      _el$2.style.setProperty("position", "absolute");

      _el$2.style.setProperty("top", "0");

      _el$2.style.setProperty("left", "0");

      _el$2.style.setProperty("width", "100%");

      _el$2.style.setProperty("height", "100%");

      effect(_p$ => {
        const _v$ = props_.height,
              _v$2 = props_.width,
              _v$3 = `listennotes-${props.episodeId}`,
              _v$4 = `//www.listennotes.com/podcasts/${props.episodeId}/embed/`;
        _v$ !== _p$._v$ && _el$.style.setProperty("height", _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && _el$.style.setProperty("width", _p$._v$2 = _v$2);
        _v$3 !== _p$._v$3 && setAttribute(_el$2, "title", _p$._v$3 = _v$3);
        _v$4 !== _p$._v$4 && setAttribute(_el$2, "src", _p$._v$4 = _v$4);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined,
        _v$3: undefined,
        _v$4: undefined
      });

      return _el$;
    }

  });
};

const pinterestClasses = ['pinterest-pin', 'pinterest-board', 'pinterest-follow-button'].map(pinClass => `.${pinClass}`).join(',');
const pinterestEmbedScript = '!function(a,b,c){var d,e,f;d="PIN_"+~~((new Date).getTime()/864e5),a[d]?a[d]+=1:(a[d]=1,a.setTimeout(function(){e=b.getElementsByTagName("SCRIPT")[0],f=b.createElement("SCRIPT"),f.type="text/javascript",f.async=!0,f.src=c.mainUrl+"?"+Math.random(),e.parentNode.insertBefore(f,e)},10))}(window,document,{mainUrl:"//assets.pinterest.com/js/pinit_main.js"});';
const handlePinterestBuild = () => {
  if (document.querySelector(pinterestClasses) && !window.PinUtils) createScriptLoader({
    src: pinterestEmbedScript
  });else window.PinUtils?.build();
};

const _tmpl$$k = /*#__PURE__*/template(`<a class="pinterest-pin" data-pin-do="embedPin"></a>`, 2);
const Pin = props => {
  const props_ = mergeProps({
    size: 'small'
  }, props);
  return createComponent(GeneralObserver, {
    onEnter: handlePinterestBuild,

    get children() {
      const _el$ = _tmpl$$k.cloneNode(true);

      effect(_p$ => {
        const _v$ = props_.size,
              _v$2 = `//www.pinterest.com/pin/${props_.pinId}`;
        _v$ !== _p$._v$ && setAttribute(_el$, "data-pin-width", _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$, "href", _p$._v$2 = _v$2);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined
      });

      return _el$;
    }

  });
};

const _tmpl$$j = /*#__PURE__*/template(`<a class="pinterest-board"></a>`, 2);
const PinterestBoard = props => {
  const props_ = mergeProps({
    width: 400,
    height: 250,
    imageWidth: 80,
    variant: 'board'
  }, props);
  return createComponent(GeneralObserver, {
    onEnter: handlePinterestBuild,

    get children() {
      const _el$ = _tmpl$$j.cloneNode(true);

      effect(_p$ => {
        const _v$ = `embed${props_.variant.charAt(0).toUpperCase()}${props_.variant.slice(1)}`,
              _v$2 = props_.width,
              _v$3 = props_.height,
              _v$4 = props_.imageWidth,
              _v$5 = `//www.pinterest.com/${props_.pinterestLink}`;
        _v$ !== _p$._v$ && setAttribute(_el$, "data-pin-do", _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$, "data-pin-board-width", _p$._v$2 = _v$2);
        _v$3 !== _p$._v$3 && setAttribute(_el$, "data-pin-scale-height", _p$._v$3 = _v$3);
        _v$4 !== _p$._v$4 && setAttribute(_el$, "data-pin-scale-width", _p$._v$4 = _v$4);
        _v$5 !== _p$._v$5 && setAttribute(_el$, "href", _p$._v$5 = _v$5);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined,
        _v$3: undefined,
        _v$4: undefined,
        _v$5: undefined
      });

      return _el$;
    }

  });
};

const _tmpl$$i = /*#__PURE__*/template(`<a class="pinterest-follow-button" data-pin-do="buttonFollow"></a>`, 2);
const PinterestFollowButton = props => createComponent(GeneralObserver, {
  onEnter: handlePinterestBuild,

  get children() {
    const _el$ = _tmpl$$i.cloneNode(true);

    insert(_el$, () => `Follow @${props.username}`);

    effect(() => setAttribute(_el$, "href", `//www.pinterest.com/${props.username}/`));

    return _el$;
  }

});

const _tmpl$$h = /*#__PURE__*/template(`<div class="simplecast-episode-solid-social"><iframe class="simplecast-episode" seamless></iframe></div>`, 4);
const SimplecastEpisode = props => {
  const props_ = mergeProps({
    theme: `light`
  }, props);
  return createComponent(GeneralObserver, {
    get children() {
      const _el$ = _tmpl$$h.cloneNode(true),
            _el$2 = _el$.firstChild;

      _el$.style.setProperty("position", "relative");

      _el$.style.setProperty("height", "200px");

      _el$.style.setProperty("width", "100%");

      _el$2.style.setProperty("position", "absolute");

      _el$2.style.setProperty("top", "0");

      _el$2.style.setProperty("left", "0");

      _el$2.style.setProperty("width", "100%");

      _el$2.style.setProperty("height", "100%");

      effect(_p$ => {
        const _v$ = `simplecast-${props_.episodeId}`,
              _v$2 = `//player.simplecast.com/${props_.episodeId}${props_.theme === `dark` ? `?dark=true` : ``}`;
        _v$ !== _p$._v$ && setAttribute(_el$2, "title", _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$2, "src", _p$._v$2 = _v$2);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined
      });

      return _el$;
    }

  });
};

const _tmpl$$g = /*#__PURE__*/template(`<div class="snack" data-snack-preview="true"></div>`, 2);
const scriptUrl = '//snack.expo.io/embed.js';
const Snack = props => {
  const props_ = mergeProps({
    platform: 'web',
    theme: 'light'
  }, props);
  return createComponent(GeneralObserver, {
    onEnter: () => createScriptLoader({
      src: scriptUrl
    }),

    get children() {
      const _el$ = _tmpl$$g.cloneNode(true);

      _el$.style.setProperty("overflow", "hidden");

      _el$.style.setProperty("background", "#F9F9F9");

      _el$.style.setProperty("border", "1px solid var(--color-border)");

      _el$.style.setProperty("border-radius", "4px");

      _el$.style.setProperty("height", "505px");

      _el$.style.setProperty("width", "100%");

      effect(_p$ => {
        const _v$ = props_.snackId,
              _v$2 = props_.platform,
              _v$3 = props_.theme;
        _v$ !== _p$._v$ && setAttribute(_el$, "data-snack-id", _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$, "data-snack-platform", _p$._v$2 = _v$2);
        _v$3 !== _p$._v$3 && setAttribute(_el$, "data-snack-theme", _p$._v$3 = _v$3);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined,
        _v$3: undefined
      });

      return _el$;
    }

  });
};

const _tmpl$$f = /*#__PURE__*/template(`<iframe class="soundcloud" allow="autoplay"></iframe>`, 2);
const SoundCloud = props => {
  const props_ = mergeProps({
    width: '100%',
    height: 'auto',
    autoPlay: false,
    visual: false,
    color: '23ff00f5'
  }, props);
  return createComponent(GeneralObserver, {
    get children() {
      const _el$ = _tmpl$$f.cloneNode(true);

      effect(_p$ => {
        const _v$ = `sound-cloud-${props_.soundCloudLink}`,
              _v$2 = props_.width,
              _v$3 = props_.height,
              _v$4 = `//w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/${props_.soundCloudLink}&color=%23${props_.color}&auto_play=${props_.autoPlay.toString()}&visual=${props_.visual.toString()}`;
        _v$ !== _p$._v$ && setAttribute(_el$, "title", _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$, "width", _p$._v$2 = _v$2);
        _v$3 !== _p$._v$3 && setAttribute(_el$, "height", _p$._v$3 = _v$3);
        _v$4 !== _p$._v$4 && setAttribute(_el$, "src", _p$._v$4 = _v$4);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined,
        _v$3: undefined,
        _v$4: undefined
      });

      return _el$;
    }

  });
};

const _tmpl$$e = /*#__PURE__*/template(`<iframe class="spotify" allow="autoplay; clipboard-write; encrypted-media; fullscreen; picture-in-picture" frameborder="0"></iframe>`, 2);
const Spotify = props => {
  const props_ = mergeProps({
    width: '100%',
    height: 325
  }, props);
  return createComponent(GeneralObserver, {
    get children() {
      const _el$ = _tmpl$$e.cloneNode(true);

      _el$.style.setProperty("border-radius", "14px");

      effect(_p$ => {
        const _v$ = `spotify-${props_.spotifyLink}`,
              _v$2 = `//open.spotify.com/embed/${props_.spotifyLink}${props_.theme === 'dark' ? '?theme=0' : ''}`,
              _v$3 = props_.width,
              _v$4 = props_.height;
        _v$ !== _p$._v$ && setAttribute(_el$, "title", _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$, "src", _p$._v$2 = _v$2);
        _v$3 !== _p$._v$3 && setAttribute(_el$, "width", _p$._v$3 = _v$3);
        _v$4 !== _p$._v$4 && setAttribute(_el$, "height", _p$._v$4 = _v$4);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined,
        _v$3: undefined,
        _v$4: undefined
      });

      return _el$;
    }

  });
};

const _tmpl$$d = /*#__PURE__*/template(`<div class="strava-solid-social"><iframe class="strava" height="100%" width="100%"></iframe></div>`, 4);
const Strava = props => createComponent(GeneralObserver, {
  get children() {
    const _el$ = _tmpl$$d.cloneNode(true),
          _el$2 = _el$.firstChild;

    _el$.style.setProperty("position", "relative");

    _el$.style.setProperty("height", "350px");

    _el$.style.setProperty("max-width", "568px");

    _el$.style.setProperty("width", "100%");

    _el$.style.setProperty("overflow", "auto");

    _el$2.style.setProperty("min-width", "380px");

    effect(_p$ => {
      const _v$ = `strava-${props.activityId}`,
            _v$2 = `//www.strava.com/activities/${props.activityId}`;
      _v$ !== _p$._v$ && setAttribute(_el$2, "title", _p$._v$ = _v$);
      _v$2 !== _p$._v$2 && setAttribute(_el$2, "src", _p$._v$2 = _v$2);
      return _p$;
    }, {
      _v$: undefined,
      _v$2: undefined
    });

    return _el$;
  }

});

const handleTikTokLoad = () => {
  if (document.querySelector('.tiktok') && !window.tiktok) createScriptLoader({
    src: '//www.tiktok.com/embed.js'
  });
};

const _tmpl$$c = /*#__PURE__*/template(`<blockquote class="tiktok"><section><a></a></section></blockquote>`, 6);
const TikTok = props => createComponent(GeneralObserver, {
  onEnter: handleTikTokLoad,

  get children() {
    const _el$ = _tmpl$$c.cloneNode(true),
          _el$2 = _el$.firstChild,
          _el$3 = _el$2.firstChild;

    insert(_el$3, () => !window.tiktok && '');

    effect(_p$ => {
      const _v$ = `//www.tiktok.com/${props.tikTokId}`,
            _v$2 = props.tikTokId.split('/').pop(),
            _v$3 = `//tiktok.com/${props.tikTokId}`;

      _v$ !== _p$._v$ && setAttribute(_el$, "cite", _p$._v$ = _v$);
      _v$2 !== _p$._v$2 && setAttribute(_el$, "data-video-id", _p$._v$2 = _v$2);
      _v$3 !== _p$._v$3 && setAttribute(_el$3, "href", _p$._v$3 = _v$3);
      return _p$;
    }, {
      _v$: undefined,
      _v$2: undefined,
      _v$3: undefined
    });

    return _el$;
  }

});

function constructTwitchURL(twitchId, channel, collection, baseUrl) {
  const sourceBlocks = [baseUrl];

  if (twitchId) {
    sourceBlocks.push(`&video=v${twitchId}`);
  } else if (channel) {
    sourceBlocks.push(`&channel=${channel}`);
  } else if (collection) {
    sourceBlocks.push(`&collection=${collection}`);
  }

  return sourceBlocks.join('');
}

const _tmpl$$b = /*#__PURE__*/template(`<div class="twitch-solid-social"><iframe class="twitch" allow="autoplay; fullscreen"></iframe></div>`, 4);
const Twitch = props => {
  const props_ = mergeProps({
    parent: 'localhost',
    autoPlay: false,
    skipTo: {
      h: 0,
      m: 0,
      s: 0
    },
    channel: '',
    collection: ''
  }, props);
  const title = createMemo(() => props_.twitchId ? `twitch-${props_.twitchId}` : `twitch`);
  const baseUrl = createMemo(() => `//player.twitch.tv/?autoplay=${props_.autoPlay.toString()}&t=${props_.skipTo.h ?? 0}h${props_.skipTo.m}m${props_.skipTo.s}s&parent=${props_.parent}`);
  const constructedSourceURL = createMemo(() => constructTwitchURL(props_.twitchId, props_.channel, props_.collection, baseUrl()));
  return createComponent(GeneralObserver, {
    get children() {
      const _el$ = _tmpl$$b.cloneNode(true),
            _el$2 = _el$.firstChild;

      _el$2.style.setProperty("position", "absolute");

      _el$2.style.setProperty("top", "0");

      _el$2.style.setProperty("left", "0");

      _el$2.style.setProperty("width", "100%");

      _el$2.style.setProperty("height", "100%");

      effect(_p$ => {
        const _v$ = {
          position: 'relative',
          width: '100%',
          ...getPadding$1('16:9')
        },
              _v$2 = title(),
              _v$3 = constructedSourceURL();

        _p$._v$ = style(_el$, _v$, _p$._v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$2, "title", _p$._v$2 = _v$2);
        _v$3 !== _p$._v$3 && setAttribute(_el$2, "src", _p$._v$3 = _v$3);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined,
        _v$3: undefined
      });

      return _el$;
    }

  });
};

const twttrClasses = ['twitter-tweet', 'twitter-follow-button', 'twitter-hashtag-button', 'twitter-list', 'twitter-mention-button', 'twitter-timeline'].map(twttrClass => `.${twttrClass}`).join(',');

const twttrLoad = () => document.querySelectorAll(twttrClasses).forEach(element => void window.twttr?.widgets.load(element));

const handleTwttrLoad = () => {
  if (document.querySelector(twttrClasses) && !window.twttr) createScriptLoader({
    src: '//platform.twitter.com/widgets.js'
  });else twttrLoad();
};
const handleTwttrUpdate = (targetElement, {
  theme
}) => {
  const tweet = document.querySelector(targetElement);
  const source = tweet?.getAttribute('src');
  if (source) tweet?.setAttribute('src', source.replace(/theme=([^&]*)/, `theme=${theme}`));
};

const _tmpl$$a = /*#__PURE__*/template(`<div class="twitter-solid-social"><blockquote class="twitter-tweet"><a></a></blockquote></div>`, 6);
const Tweet = props => {
  const props_ = mergeProps({
    theme: 'light',
    align: 'left',
    hideConversation: false
  }, props);
  const tweetId = createMemo(() => props_.tweetLink.split('/').at(-1) ?? '');
  createEffect(on(() => [props_.align, props_.theme, props_.hideConversation, props_.tweetLink], () => handleTwttrUpdate(`iframe[data-tweet-id="${tweetId()}"]`, props_), {
    defer: true
  }));
  return createComponent(GeneralObserver, {
    onEnter: handleTwttrLoad,

    get children() {
      const _el$ = _tmpl$$a.cloneNode(true),
            _el$2 = _el$.firstChild,
            _el$3 = _el$2.firstChild;

      _el$.style.setProperty("overflow", "auto");

      insert(_el$3, () => window.twttr && '');

      effect(_p$ => {
        const _v$ = `twitter-tweet-${tweetId()}`,
              _v$2 = props_.theme,
              _v$3 = props_.align,
              _v$4 = props_.hideConversation ? 'none' : '',
              _v$5 = `//twitter.com/${props_.tweetLink}?ref_src=twsrc%5Etfw`;

        _v$ !== _p$._v$ && setAttribute(_el$, "id", _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$2, "data-theme", _p$._v$2 = _v$2);
        _v$3 !== _p$._v$3 && setAttribute(_el$2, "data-align", _p$._v$3 = _v$3);
        _v$4 !== _p$._v$4 && setAttribute(_el$2, "data-conversation", _p$._v$4 = _v$4);
        _v$5 !== _p$._v$5 && setAttribute(_el$3, "href", _p$._v$5 = _v$5);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined,
        _v$3: undefined,
        _v$4: undefined,
        _v$5: undefined
      });

      return _el$;
    }

  });
};

const _tmpl$$9 = /*#__PURE__*/template(`<a class="twitter-follow-button"></a>`, 2);
const TwitterFollowButton = props => {
  const props_ = mergeProps({
    showFollowers: false,
    showUsername: true,
    size: 'small'
  }, props);
  return createComponent(GeneralObserver, {
    onEnter: handleTwttrLoad,

    get children() {
      const _el$ = _tmpl$$9.cloneNode(true);

      insert(_el$, () => `Follow @${props_.username}`);

      effect(_p$ => {
        const _v$ = `//twitter.com/${props_.username}?ref_src=twsrc%5Etfw`,
              _v$2 = props_.showFollowers,
              _v$3 = props_.showUsername,
              _v$4 = props_.size;
        _v$ !== _p$._v$ && setAttribute(_el$, "href", _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$, "data-show-count", _p$._v$2 = _v$2);
        _v$3 !== _p$._v$3 && setAttribute(_el$, "data-show-screen-name", _p$._v$3 = _v$3);
        _v$4 !== _p$._v$4 && setAttribute(_el$, "data-size", _p$._v$4 = _v$4);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined,
        _v$3: undefined,
        _v$4: undefined
      });

      return _el$;
    }

  });
};

const _tmpl$$8 = /*#__PURE__*/template(`<a class="twitter-hashtag-button"></a>`, 2);
const TwitterHashtagButton = props => {
  const props_ = mergeProps({
    size: 'small'
  }, props);
  return createComponent(GeneralObserver, {
    onEnter: handleTwttrLoad,

    get children() {
      const _el$ = _tmpl$$8.cloneNode(true);

      insert(_el$, () => `Tweet #${props_.hashtag}`);

      effect(_p$ => {
        const _v$ = `//twitter.com/intent/tweet?button_hashtag=${props_.hashtag}&ref_src=twsrc%5Etfw`,
              _v$2 = props_.size;
        _v$ !== _p$._v$ && setAttribute(_el$, "href", _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$, "data-size", _p$._v$2 = _v$2);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined
      });

      return _el$;
    }

  });
};

const _tmpl$$7 = /*#__PURE__*/template(`<div class="twitter-solid-social"><a class="twitter-list"></a></div>`, 4);
const TwitterList = props => {
  const props_ = mergeProps({
    theme: 'light',
    width: '498px',
    height: undefined
  }, props);
  return createComponent(GeneralObserver, {
    onEnter: handleTwttrLoad,

    get children() {
      const _el$ = _tmpl$$7.cloneNode(true),
            _el$2 = _el$.firstChild;

      _el$.style.setProperty("overflow", "auto");

      insert(_el$2, () => `A Twitter List by @${props_.username}`);

      effect(_p$ => {
        const _v$ = props_.theme,
              _v$2 = props_.width,
              _v$3 = props_.height,
              _v$4 = `//twitter.com/${props_.username}/lists/${props_.listName}?ref_src=twsrc%5Etfw`;
        _v$ !== _p$._v$ && setAttribute(_el$2, "data-theme", _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$2, "data-width", _p$._v$2 = _v$2);
        _v$3 !== _p$._v$3 && setAttribute(_el$2, "data-height", _p$._v$3 = _v$3);
        _v$4 !== _p$._v$4 && setAttribute(_el$2, "href", _p$._v$4 = _v$4);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined,
        _v$3: undefined,
        _v$4: undefined
      });

      return _el$;
    }

  });
};

const _tmpl$$6 = /*#__PURE__*/template(`<a class="twitter-mention-button"></a>`, 2);
const TwitterMentionButton = props => {
  const props_ = mergeProps({
    size: 'small'
  }, props);
  return createComponent(GeneralObserver, {
    onEnter: handleTwttrLoad,

    get children() {
      const _el$ = _tmpl$$6.cloneNode(true);

      insert(_el$, () => `Tweet to @${props_.username}`);

      effect(_p$ => {
        const _v$ = `//twitter.com/intent/tweet?screen_name=${props_.username}&ref_src=twsrc%5Etfw`,
              _v$2 = props_.size;
        _v$ !== _p$._v$ && setAttribute(_el$, "href", _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$, "data-size", _p$._v$2 = _v$2);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined
      });

      return _el$;
    }

  });
};

const _tmpl$$5 = /*#__PURE__*/template(`<div class="twitter-solid-social"><a class="twitter-timeline"></a></div>`, 4);
const TwitterTimeline = props => {
  const props_ = mergeProps({
    theme: 'light',
    width: '498px'
  }, props);
  return createComponent(GeneralObserver, {
    onEnter: handleTwttrLoad,

    get children() {
      const _el$ = _tmpl$$5.cloneNode(true),
            _el$2 = _el$.firstChild;

      _el$.style.setProperty("overflow", "auto");

      insert(_el$2, () => `Tweets by @${props_.username}`);

      effect(_p$ => {
        const _v$ = props_.theme,
              _v$2 = props_.width,
              _v$3 = props_.height,
              _v$4 = `//twitter.com/${props_.username}${props_.showLikes ? `/likes` : ''}?ref_src=twsrc%5Etfw`;
        _v$ !== _p$._v$ && setAttribute(_el$2, "data-theme", _p$._v$ = _v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$2, "data-width", _p$._v$2 = _v$2);
        _v$3 !== _p$._v$3 && setAttribute(_el$2, "data-height", _p$._v$3 = _v$3);
        _v$4 !== _p$._v$4 && setAttribute(_el$2, "href", _p$._v$4 = _v$4);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined,
        _v$3: undefined,
        _v$4: undefined
      });

      return _el$;
    }

  });
};

const _tmpl$$4 = /*#__PURE__*/template(`<div class="vimeo-solid-social"><iframe class="vimeo" allow="autoplay; fullscreen"></iframe></div>`, 4);
const Vimeo = props => {
  const props_ = mergeProps({
    autoPlay: false,
    skipTo: {
      h: 0,
      m: 0,
      s: 0
    }
  }, props);
  return createComponent(GeneralObserver, {
    get children() {
      const _el$ = _tmpl$$4.cloneNode(true),
            _el$2 = _el$.firstChild;

      _el$2.style.setProperty("position", "absolute");

      _el$2.style.setProperty("top", "0");

      _el$2.style.setProperty("left", "0");

      _el$2.style.setProperty("width", "100%");

      _el$2.style.setProperty("height", "100%");

      effect(_p$ => {
        const _v$ = {
          position: 'relative',
          width: '100%',
          ...getPadding$1('16:9')
        },
              _v$2 = `vimeo-${props_.vimeoId}`,
              _v$3 = `//player.vimeo.com/video/${props_.vimeoId}?autoplay=${props_.autoPlay.toString()}#t=${props_.skipTo.h ?? 0}h${props_.skipTo.m}m${props_.skipTo.s}s`;
        _p$._v$ = style(_el$, _v$, _p$._v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$2, "title", _p$._v$2 = _v$2);
        _v$3 !== _p$._v$3 && setAttribute(_el$2, "src", _p$._v$3 = _v$3);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined,
        _v$3: undefined
      });

      return _el$;
    }

  });
};

function getPadding(aspectRatio) {
  const regExp = /^([1-9]\d*):([1-9]\d*)$/;
  const [, width, height] = regExp.exec(aspectRatio) ?? ['', '1', '1'];
  return {
    paddingTop: `${100 * Number.parseInt(height, 10) / Number.parseInt(width, 10)}%`
  };
}

const _tmpl$$3 = /*#__PURE__*/template(`<div class="whimsical-solid-social"><iframe class="whimsical" allowfullscreen></iframe></div>`, 4);
const Whimsical = props => {
  const props_ = mergeProps({
    aspectRatio: '1:1'
  }, props);
  return createComponent(GeneralObserver, {
    get children() {
      const _el$ = _tmpl$$3.cloneNode(true),
            _el$2 = _el$.firstChild;

      _el$2.style.setProperty("position", "absolute");

      _el$2.style.setProperty("top", "0");

      _el$2.style.setProperty("left", "0");

      _el$2.style.setProperty("width", "100%");

      _el$2.style.setProperty("height", "100%");

      effect(_p$ => {
        const _v$ = {
          position: 'relative',
          width: '100%',
          ...getPadding(props_.aspectRatio)
        },
              _v$2 = `whimsical-${props_.diagramId}`,
              _v$3 = `//whimsical.com/embed/${props_.diagramId}`;
        _p$._v$ = style(_el$, _v$, _p$._v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$2, "title", _p$._v$2 = _v$2);
        _v$3 !== _p$._v$3 && setAttribute(_el$2, "src", _p$._v$3 = _v$3);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined,
        _v$3: undefined
      });

      return _el$;
    }

  });
};

const _tmpl$$2 = /*#__PURE__*/template(`<iframe class="wikipedia"></iframe>`, 2),
      _tmpl$2 = /*#__PURE__*/template(`<div></div>`, 2);
const Wikipedia = props => {
  const props_ = mergeProps({
    height: 600
  }, props);

  const getWikipediaHtml = async wikipediaLink => {
    const response = await fetch(`//en.wikipedia.org/api/rest_v1/page/html/${wikipediaLink}`);
    const text = await response.text();
    return text.replace(/<a rel="mw:WikiLink"/g, '<a target="_blank" rel="mw:WikiLink"');
  };

  const [wiki] = createResource(() => props_.wikipediaLink, getWikipediaHtml);
  return createComponent(GeneralObserver, {
    get children() {
      return createComponent(ErrorBoundary, {
        fallback: error => (() => {
          const _el$2 = _tmpl$2.cloneNode(true);

          insert(_el$2, () => String(error));

          return _el$2;
        })(),

        get children() {
          return createComponent(Suspense, {
            fallback: "",

            get children() {
              const _el$ = _tmpl$$2.cloneNode(true);

              _el$.style.setProperty("width", "100%");

              effect(_p$ => {
                const _v$ = props_.wikipediaLink,
                      _v$2 = typeof props_.height === 'string' ? props_.height : `${props_.height}px`,
                      _v$3 = wiki();

                _v$ !== _p$._v$ && setAttribute(_el$, "title", _p$._v$ = _v$);
                _v$2 !== _p$._v$2 && _el$.style.setProperty("min-height", _p$._v$2 = _v$2);
                _v$3 !== _p$._v$3 && setAttribute(_el$, "srcdoc", _p$._v$3 = _v$3);
                return _p$;
              }, {
                _v$: undefined,
                _v$2: undefined,
                _v$3: undefined
              });

              return _el$;
            }

          });
        }

      });
    }

  });
};

let isWistiaAdded = false;
const embedUrl = `//fast.wistia.net/assets/external/E-v1.js`;
const handleWistiaLoad = () => {
  if (!isWistiaAdded) createScriptLoader({
    src: embedUrl,
    onload: () => isWistiaAdded = true
  });
};

const _tmpl$$1 = /*#__PURE__*/template(`<div class="wistia-container-solid-social"><iframe class="wistia-solid-social"></iframe></div>`, 4);
const Wistia = props => {
  const props_ = mergeProps({
    allowfullscreen: true,
    aspectRatio: '16:9',
    width: '100%',
    height: '100%',
    autoPlay: false
  }, props);
  return createComponent(GeneralObserver, {
    onEnter: handleWistiaLoad,

    get children() {
      const _el$ = _tmpl$$1.cloneNode(true),
            _el$2 = _el$.firstChild;

      _el$2.style.setProperty("position", "absolute");

      _el$2.style.setProperty("top", "0");

      _el$2.style.setProperty("left", "0");

      effect(_p$ => {
        const _v$ = {
          position: 'relative',
          width: '100%',
          ...getPadding$1(props_.aspectRatio)
        },
              _v$2 = `wistia-${props_.videoId}`,
              _v$3 = `//fast.wistia.net/embed/iframe/${props_.videoId}${props.autoPlay ? '?autoPlay=true' : ''}`,
              _v$4 = `autoplay; ${props_.allowfullscreen ? 'fullscreen' : ''}`,
              _v$5 = props_.width,
              _v$6 = props_.height;
        _p$._v$ = style(_el$, _v$, _p$._v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$2, "title", _p$._v$2 = _v$2);
        _v$3 !== _p$._v$3 && setAttribute(_el$2, "src", _p$._v$3 = _v$3);
        _v$4 !== _p$._v$4 && setAttribute(_el$2, "allow", _p$._v$4 = _v$4);
        _v$5 !== _p$._v$5 && _el$2.style.setProperty("width", _p$._v$5 = _v$5);
        _v$6 !== _p$._v$6 && _el$2.style.setProperty("height", _p$._v$6 = _v$6);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined,
        _v$3: undefined,
        _v$4: undefined,
        _v$5: undefined,
        _v$6: undefined
      });

      return _el$;
    }

  });
};

const _tmpl$ = /*#__PURE__*/template(`<div class="youtube-solid-social"><iframe class="youtube" allow="accelerometer; autoplay; encrypted-media; fullscreen; gyroscope; picture-in-picture"></iframe></div>`, 4);
const YouTube = props => {
  const props_ = mergeProps({
    aspectRatio: '16:9',
    autoPlay: false,
    skipTo: {
      h: 0,
      m: 0,
      s: 0
    },
    noCookie: false
  }, props);
  const startTime = createMemo(() => {
    const {
      h,
      m,
      s
    } = props_.skipTo;
    return (h ?? 0) * 60 + m * 60 + s;
  });
  const source = createMemo(() => `//www.youtube${props_.noCookie ? '-nocookie' : ''}.com/embed/${props_.youTubeId ? `${props_.youTubeId}?&autoplay=${props_.autoPlay.toString()}&start=${startTime()}` : `&videoseries?list=${props_.youTubePlaylistId ?? ''}`}`);
  return createComponent(GeneralObserver, {
    get children() {
      const _el$ = _tmpl$.cloneNode(true),
            _el$2 = _el$.firstChild;

      _el$2.style.setProperty("position", "absolute");

      _el$2.style.setProperty("top", "0");

      _el$2.style.setProperty("left", "0");

      _el$2.style.setProperty("width", "100%");

      _el$2.style.setProperty("height", "100%");

      effect(_p$ => {
        const _v$ = {
          position: 'relative',
          width: '100%',
          ...getPadding$1(props_.aspectRatio)
        },
              _v$2 = `youtube-${props_.youTubeId ?? props_.youTubePlaylistId ?? ''}`,
              _v$3 = source();

        _p$._v$ = style(_el$, _v$, _p$._v$);
        _v$2 !== _p$._v$2 && setAttribute(_el$2, "title", _p$._v$2 = _v$2);
        _v$3 !== _p$._v$3 && setAttribute(_el$2, "src", _p$._v$3 = _v$3);
        return _p$;
      }, {
        _v$: undefined,
        _v$2: undefined,
        _v$3: undefined
      });

      return _el$;
    }

  });
};

export { AirtableBase, AirtableForm, Buzzsprout, Cinnamon, CodePen, CodeSandbox, EggheadLesson, Figma, Flickr, Gist, Instagram, Lbry, LinkedInBadge, ListenNotesEpisode, Pin, PinterestBoard, PinterestFollowButton, SimplecastEpisode, Snack, SoundCloud, Spotify, Strava, TikTok, Tweet, Twitch, TwitterFollowButton, TwitterHashtagButton, TwitterList, TwitterMentionButton, TwitterTimeline, Vimeo, Whimsical, Wikipedia, Wistia, YouTube };
//# sourceMappingURL=index.js.map
